pub struct SystemClockDescriptor {
pub external_clock_reference: bool,
pub clock_accuracy_integer: u8,
pub clock_accuracy_exponent: u8,
}Expand description
system_clock_descriptor body (2.6.20 Table 2-54).
clock_accuracy_integer × 10^(-clock_accuracy_exponent) gives the
fractional frequency accuracy of the program clock in parts per
million (2.6.21). When clock_accuracy_integer == 0 the spec
defines the accuracy as 30 ppm.
Fields
external_clock_reference: boolexternal_clock_reference_indicator — when true, the clock
is derived from an external frequency reference at the decoder.
clock_accuracy_integer: u86-bit clock_accuracy_integer.
clock_accuracy_exponent: u83-bit clock_accuracy_exponent.